#ifndef __LOADNFIdotH__
#define __LOADNFIdotH__

/********************************************************************/

// Reads in all of the directory and file informtion for the given NFI
// file. Returns a pointer to a dynmaically allocated NFIFile 
// structure on success or null on error.
//
// The file here will be opened for read access only. This is so that
// editing operations can read data from this file as needed when
// creating the new archive.
NFIFile *openNFIFile (ConfigInfo *config);

// Allocate and create a ne NFI file with the given name. 
//
// This will open the file for writing, truncating any existing file 
// that may exist.
//
// In this case, the file will be empty, so there will be no need to
// pull information from it in order to create the new file. However,
// we leave the file open until we are ready to create a new file. This
// makes sure that we can actually access the file when the time comes,
// so we don't waste time with other operations only to find we can't
// write the file we want.
//
// Returns NULL on error (unable to create the file named).
NFIFile *createNFIFile (ConfigInfo *config);

// Print out the directory of the given NFI file, which shows any
// operations that may have been done on it, and how they will be saved.
void printNFIDirectory (NFIFile *file , ConfigInfo *config);

// Close and get rid of a loaded NFI file. File can be NULL, in which
// case nothing happens. If the file has had any changes made to it
// since it was opened/created, it will be re-written. 
//
// Changes are only written out if noSave is false. If noSave is true,
// then no save operation occurs. This is used by the --no-action/-n
// command to stop any changes from being commited.
//
// If isDebugging is set to YES, the directory of the file being output
// is displayed, along with the internal path structure of the archive.
// This can help debug problems with commands interacting improperly.
//
// The return value should be EXIT_SUCCESS or EXIT_FAILURE to indicate
// if the close worked or not (particularly in the case of a save operation)
int closeNFIFile (NFIFile *file , SDL_bool noSave , ConfigInfo *config);

/********************************************************************/

#endif

